RecordMode

Trait RecordMode 

pub trait RecordMode {
    type Op;

    // Required method
    fn enqueue_record(
        &mut self,
        stream: &Arc<CudaStream>,
        op: Self::Op,
    ) -> Result<(), GpuError>;
}
Library-actor opt-in to capture-mode enqueue.

Implementations enqueue op onto stream synchronously and return without awaiting completion. The caller is responsible for any downstream CudaEvent recording / wait.

Required Associated Types

type Op

The operation type, typically a thin enum mirroring the actor’s public Msg enum but stripped of oneshot::Sender reply channels.

Required Methods

fn enqueue_record( &mut self, stream: &Arc<CudaStream>, op: Self::Op, ) -> Result<(), GpuError>

Implementors

Source

impl RecordMode for MemcpyRecorder

Source

impl<'a> RecordMode for BlasRecorder<'a>

Source

impl<'a> RecordMode for FftRecorder<'a>

Available on crate feature cufft only.
Source

impl<'a> RecordMode for RngRecorder<'a>

Available on crate feature curand only.